@@ -1,5 +1,4 @@
 import asyncio
-import logging
 import pickle
 from urllib.parse import urlparse
 
@@ -10,13 +9,12 @@ except ImportError:
 
 from .asyncio_pubsub_manager import AsyncPubSubManager
 
-logger = logging.getLogger('socketio')
-
 
 def _parse_redis_url(url):
     p = urlparse(url)
-    if p.scheme != 'redis':
+    if p.scheme not in {'redis', 'rediss'}:
         raise ValueError('Invalid redis url')
+    ssl = p.scheme == 'rediss'
     host = p.hostname or 'localhost'
     port = p.port or 6379
     password = p.password
@@ -24,7 +22,7 @@ def _parse_redis_url(url):
         db = int(p.path[1:])
     else:
         db = 0
-    return host, port, password, db
+    return host, port, password, db, ssl
 
 
 class AsyncRedisManager(AsyncPubSubManager):  # pragma: no cover
@@ -42,7 +40,8 @@ class AsyncRedisManager(AsyncPubSubManager):  # pragma: no cover
             'redis://hostname:port/0'))
 
     :param url: The connection URL for the Redis server. For a default Redis
-                store running on the same host, use ``redis://``.
+                store running on the same host, use ``redis://``.  To use an
+                SSL connection, use ``rediss://``.
     :param channel: The channel name on which the server sends and receives
                     notifications. Must be the same in all the servers.
     :param write_only: If set ot ``True``, only initialize to emit events. The
@@ -52,15 +51,17 @@ class AsyncRedisManager(AsyncPubSubManager):  # pragma: no cover
     name = 'aioredis'
 
     def __init__(self, url='redis://localhost:6379/0', channel='socketio',
-                 write_only=False):
+                 write_only=False, logger=None):
         if aioredis is None:
             raise RuntimeError('Redis package is not installed '
                                '(Run "pip install aioredis" in your '
                                'virtualenv).')
-        self.host, self.port, self.password, self.db = _parse_redis_url(url)
+        (
+            self.host, self.port, self.password, self.db, self.ssl
+        ) = _parse_redis_url(url)
         self.pub = None
         self.sub = None
-        super().__init__(channel=channel, write_only=write_only)
+        super().__init__(channel=channel, write_only=write_only, logger=logger)
 
     async def _publish(self, data):
         retry = True
@@ -69,16 +70,19 @@ class AsyncRedisManager(AsyncPubSubManager):  # pragma: no cover
                 if self.pub is None:
                     self.pub = await aioredis.create_redis(
                         (self.host, self.port), db=self.db,
-                        password=self.password)
+                        password=self.password, ssl=self.ssl
+                    )
                 return await self.pub.publish(self.channel,
                                               pickle.dumps(data))
             except (aioredis.RedisError, OSError):
                 if retry:
-                    logger.error('Cannot publish to redis... retrying')
+                    self._get_logger().error('Cannot publish to redis... '
+                                             'retrying')
                     self.pub = None
                     retry = False
                 else:
-                    logger.error('Cannot publish to redis... giving up')
+                    self._get_logger().error('Cannot publish to redis... '
+                                             'giving up')
                     break
 
     async def _listen(self):
@@ -88,12 +92,14 @@ class AsyncRedisManager(AsyncPubSubManager):  # pragma: no cover
                 if self.sub is None:
                     self.sub = await aioredis.create_redis(
                         (self.host, self.port), db=self.db,
-                        password=self.password)
+                        password=self.password, ssl=self.ssl
+                    )
                 self.ch = (await self.sub.subscribe(self.channel))[0]
                 return await self.ch.get()
             except (aioredis.RedisError, OSError):
-                logger.error('Cannot receive from redis... '
-                             'retrying in {} secs'.format(retry_sleep))
+                self._get_logger().error('Cannot receive from redis... '
+                                         'retrying in '
+                                         '{} secs'.format(retry_sleep))
                 self.sub = None
                 await asyncio.sleep(retry_sleep)
                 retry_sleep *= 2
